@@ -22,7 +22,6 @@ class ExpaiProject:
     #########################
     ###      MODELS       ###
     #########################
-
     def model_list(self, search_by: str = None, exact_search: str = None):
         """
         List all models within the project
@@ -48,19 +47,19 @@ class ExpaiProject:
                                          self.server_name + "/api/projects/{}/model/list/contains/{}".format(
                                              self.project_id, search_by),
                                          headers=self.headers)
-            return generate_response(response, 'models')
+            return generate_response(response, ['models'])
 
         else:
             response = self.sess.request("GET",
                                          self.server_name + "/api/projects/{}/model/list".format(self.project_id),
                                          headers=self.headers)
 
-            return generate_response(response, 'models')
+            return generate_response(response, ['models'])
 
 
     def create_model(self, model_path: str = None, is_supervised: bool = True, model_name: str = None,
-                     model_category: str = None, model_library: str = None, model_objective: str = None,
-                     model_prediction_type: str = None, output_classes: list = None):
+                     model_summary: str = None, model_library: str = None, model_objective: str = None,
+                     model_prediction_type: str = None, output_classes: list = None, model_cutoff: float = None):
         """
         Create a new model for a project.
         :param model_path: path where your model is stored locally
@@ -70,18 +69,20 @@ class ExpaiProject:
         """
         assert model_name is not None, "To create a model you must give it a model_name"
         assert model_path is not None, "To create a model you must specify the path to the stored model"
-        assert model_category is not None, "Please, indicate the model_category. Refer to documentation for further information"
         assert model_library is not None, "Please, indicate the model_library. Refer to documentation for further information"
         assert model_objective is not None, "Please, indicate the model_objective. Refer to documentation for further information"
         assert model_prediction_type is not None, "Please, indicate the model_prediction_type. Refer to documentation for further information"
 
+        if model_cutoff is not None:
+            assert 0 < model_cutoff < 1, "Cutoff value must be between 0 and 1"
 
         data = {"model_name_des": model_name,
+                "model_summary_des": model_summary,
                 "is_supervised_flag": 1 if is_supervised else 0,
-                'model_category_des': model_category.lower(),
-                'model_library_des': model_library.lower(),
-                'model_objective_des': model_objective.lower(),
-                'model_prediction_type_des': model_prediction_type.lower(),
+                "model_cutoff_num": model_cutoff,
+                'model_library_des': model_library,
+                'model_objective_des': model_objective,
+                'model_prediction_type_des': model_prediction_type,
                 'output_classes_des': ','.join(str(e) for e in output_classes) if output_classes is not None else None}
 
         files = {'model_file': open(model_path, 'rb')}
@@ -165,8 +166,11 @@ class ExpaiProject:
     def _get_model_id_from_name(self, model_name: str = None):
 
         model_list = self.model_list()
+        model_list = model_list.get('models')
+
         if model_list is None:
             raise Exception('Model not found')
+
         for model in model_list:
             if model['model_name_des'] == model_name:
                 return model['model_id']
@@ -199,16 +203,17 @@ class ExpaiProject:
                                          self.server_name + "/api/projects/{}/sample/list/contains/{}".format(
                                              self.project_id, search_by),
                                          headers=self.headers)
-            return generate_response(response, 'samples')
+            return generate_response(response, ['samples'])
 
         else:
             response = self.sess.request("GET", self.server_name + "/api/projects/{}/sample/list".format(self.project_id),
                                     headers=self.headers)
 
-            return generate_response(response, 'samples')
+            return generate_response(response, ['samples'])
 
     def create_sample(self, sample_path: str = None, sample_name: str = None, sample_separator: str = None, sample_target_col: str = None,
-                      sample_encoding: str = 'utf-8', is_display = False, reference_sample_id: str = None, reference_sample_name: str = None):
+                      sample_encoding: str = 'utf-8', is_display = False, reference_sample_id: str = None, reference_sample_name: str = None,
+                      display_sample_id: str = None, display_sample_name: str = None):
         """
         Create a new sample for the project
         :param sample_target_col: target column for the model
@@ -231,13 +236,17 @@ class ExpaiProject:
                     logging.error(
                         "We could not find any sample matching that name. Please, try again or use reference_sample_id as parameter")
                     return False
+        else:
+            if display_sample_name is not None:
+                display_sample_id = self._get_sample_id_from_name(display_sample_name)
 
         data = {"sample_name_des": sample_name,
                 "sample_file_separator_des": sample_separator,
                 "sample_file_encoding_des": sample_encoding,
                 "sample_target_col": sample_target_col,
                 "is_display": 1 if is_display is True else 0,
-                "original_sample_id": reference_sample_id}
+                "original_sample_id": reference_sample_id,
+                "display_sample_id": display_sample_id}
 
         files = {'sample_file': open(sample_path, 'r', encoding=sample_encoding)}
 
@@ -359,8 +368,12 @@ class ExpaiProject:
 
 
     def _get_sample_id_from_name(self, sample_name: str = None):
-
         sample_list = self.sample_list()
+        sample_list = sample_list.get('samples')
+
+        if sample_list is None:
+            return None
+
         for sample in sample_list:
             if sample['sample_name_des'] == sample_name:
                 return sample['sample_id']
