@@ -53,12 +53,12 @@ class ExpaiLogin:
             response = self.sess.request("GET",
                                          self.server_name + "/api/projects/list/contains/{}".format(search_by),
                                          headers=self.headers)
-            return generate_response(response, 'projects')
+            return generate_response(response, ['projects'])
 
         else:
             response = self.sess.request("GET", self.server_name + "/api/projects/list", headers=self.headers)
 
-            return generate_response(response, 'projects')
+            return generate_response(response, ['projects'])
 
 
     def create_project(self, project_name: str = None):
@@ -155,14 +155,7 @@ class ExpaiLogin:
                                      self.server_name + "/api/models/get_allowed",
                                      headers=self.headers)
 
-        if response.ok:
-            output = {"models_category": generate_response(response, 'models_category'),
-                      "models_objective": generate_response(response, 'models_objective'),
-                      "models_prediction": generate_response(response, 'models_prediction'),
-                      "models_library": generate_response(response, 'models_library')}
-            return output
-        else:
-            return generate_response(response)
+        return generate_response(response, ['models_category', 'models_objective', 'models_prediction', 'models_library'])
 
     def get_allowed_files(self):
         """
@@ -172,8 +165,4 @@ class ExpaiLogin:
                                      self.server_name + "/api/files/get_allowed",
                                      headers=self.headers)
 
-        if response.ok:
-            output = {"files_type": generate_response(response, 'files_type')}
-            return output
-        else:
-            return generate_response(response)
+        return generate_response(response, ["files_type"])
