@@ -1,11 +1,24 @@
 from expai.expai_requests import ExpaiLogin
+import os
 
 if __name__ == '__main__':
     expaireq = ExpaiLogin(email="test@test.com", user_pass="test", api_key="6H19l-zXUzJVli2bcEMENssBjx0Ph4dnI0rmNtWcVac")
+    models = expaireq.get_allowed_models()
     projects = expaireq.project_list(search_by='Proy')
-    project = expaireq.get_project(project_name='Proyecto 1')
-    test = project.create_sample(sample_path='/Users/javi/Desktop/20201113.csv',
-                          sample_name="Sample prueba lista3", sample_separator=";", is_display=False)
+    project = expaireq.get_project(project_name='Proyecto Test DAG')
+    explainer_xgb = project.get_model_explainer("Car Selling Price Predictor XGB")
+    project.create_sample(sample_path=os.path.abspath("./car_ad_display.csv"),
+                          sample_name="Test Display",
+                          sample_separator=";",
+                          sample_encoding="latin-1",
+                          is_display=True,
+                          reference_sample_name="Test")
+    test = project.create_sample(sample_path='/Users/javi/Desktop/subir1.csv',
+                          sample_name="Sample prueba lista5", sample_separator=",", is_display=False)
+    project.append_sample(sample_path='/Users/javi/Desktop/subir2.csv',
+                          sample_name="Sample prueba lista5")
+
+    probando = project.get_sample(sample_name="Sample prueba lista5")
     projects = expaireq.project_list(exact_search='Proyecto 1')
     projects = expaireq.project_list(exact_search='Proyec 1')
     response = expaireq.delete_project(project_name="Prueba pycharm 2")
